@@ -1,5 +1,5 @@
 #!/bin/bash
-mversion=4.0
+mversion=7.1
 TTSENGINE=acapela
 
 echo "--- $TTSENGINE HTTP/TTS $mversion Installation ---"
@@ -13,11 +13,16 @@ perm_exec=775
 src=.
 dst=
 
+if [ ! -f /usr/bin/acapela ];then
+    echo "Install acapela binary in /usr/bin"
+    install -m $perm_exec $src/bin/acapela /usr/bin/acapela
+fi
+
 #part1
 #part2
 echo "Installing Web script..."
 wwwdirselect=/var/www
-echo $n "Enter apache web root directory[$wwwdirselect]: $c"
+echo -n "Enter apache web root directory[$wwwdirselect]: "
 read wwwdiruser
 if [ -n "$wwwdiruser" ]; then
 	wwwdirselect=$wwwdiruser
